
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '35.2.1',
    'branch_nick': 'release-35-LTS',
    'revision_id': 'd16287dcea81790562e5c63066feb522bf57ab8d',
    'revno': 13130
}
